# Project Instructions

<!-- DOPETASK:BEGIN -->
(disabled)
<!-- DOPETASK:END -->
<!-- CHATX:BEGIN -->
(disabled)
<!-- CHATX:END -->

Project-level instructions are maintained in sentinel blocks above.
